run!() { /* proc-macro */ }Expand description
Run cli now.
run!() instead of run(). You can use this macro to get application of cli.
See Application for more details.
run!() { /* proc-macro */ }Run cli now.
run!() instead of run(). You can use this macro to get application of cli.
See Application for more details.